HorizontalAlignment enum
Horizontal cell alignment, applied with Format.align.
Values mirror libxlsxwriter's lxw_format_alignments horizontal members.
Values
- none → const HorizontalAlignment
-
Excel's default alignment for the cell's data type.
const HorizontalAlignment(0) - left → const HorizontalAlignment
-
Left aligned.
const HorizontalAlignment(1) - center → const HorizontalAlignment
-
Centered.
const HorizontalAlignment(2) - right → const HorizontalAlignment
-
Right aligned.
const HorizontalAlignment(3) - fill → const HorizontalAlignment
-
Fill: repeat the cell value to fill the width.
const HorizontalAlignment(4) - justify → const HorizontalAlignment
-
Justified.
const HorizontalAlignment(5) - centerAcross → const HorizontalAlignment
-
Centered across the selection.
const HorizontalAlignment(6) - distributed → const HorizontalAlignment
-
Distributed.
const HorizontalAlignment(7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The libxlsxwriter enum value passed across the FFI boundary.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HorizontalAlignment> - A constant List of the values in this enum, in order of their declaration.